mailr13103 - /branches/inversion-recovery/specific_fns/relax_fit.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by sebastien . morin on June 17, 2011 - 14:40:
Author: semor
Date: Fri Jun 17 14:40:30 2011
New Revision: 13103

URL: http://svn.gna.org/viewcvs/relax?rev=13103&view=rev
Log:

Modified the specific function 'relax_fit.select_model()' to handle two of 
the new exponential names.

The 'exp' function now is named 'exp_2param_neg' and the 'inv' function, 
'exp_3param_inv_neg'.


Modified:
    branches/inversion-recovery/specific_fns/relax_fit.py

Modified: branches/inversion-recovery/specific_fns/relax_fit.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/inversion-recovery/specific_fns/relax_fit.py?rev=13103&r1=13102&r2=13103&view=diff
==============================================================================
--- branches/inversion-recovery/specific_fns/relax_fit.py (original)
+++ branches/inversion-recovery/specific_fns/relax_fit.py Fri Jun 17 14:40:30 
2011
@@ -1,6 +1,7 @@
 
###############################################################################
 #                                                                            
 #
 # Copyright (C) 2004-2009 Edward d'Auvergne                                  
 #
+# Copyright (C) 2011 Sebastien Morin                                         
 #
 #                                                                            
 #
 # This file is part of the program relax.                                    
 #
 #                                                                            
 #
@@ -461,10 +462,12 @@
         cdp.relax_times[spectrum_id] = time
 
 
-    def _select_model(self, model='exp'):
+    def _select_model(self, model='exp_2param_neg'):
         """Function for selecting the model of the exponential curve.
 
-        @keyword model: The exponential curve type.  Can be one of 'exp' or 
'inv'.
+        @keyword model: The exponential curve type.  Can be one of 8 
functions: 'exp_2param', 
+                        'exp_2param_neg', 'exp_2param_inv_neg', 
'exp_3param', 'exp_3param_neg', 
+                        'exp_3param_inv', or 'exp_3param_inv_neg'.
         @type model:    str
         """
 
@@ -480,13 +483,13 @@
         if not exists_mol_res_spin_data():
             raise RelaxNoSequenceError
 
-        # Two parameter exponential fit.
-        if model == 'exp':
-            print("Two parameter exponential fit.")
+        # Two parameter exponential decay fit.
+        if model == 'exp_2param_neg':
+            print("Two parameter exponential decay fit.")
             params = ['Rx', 'I0']
 
         # Three parameter inversion recovery fit.
-        elif model == 'inv':
+        elif model == 'exp_3param_inv_neg':
             print("Three parameter inversion recovery fit.")
             params = ['Rx', 'I0', 'Iinf']
 




Related Messages


Powered by MHonArc, Updated Fri Jun 17 15:00:02 2011